package com.atlassian.crucible.plugin.export;

import java.util.List;

import com.atlassian.crucible.spi.data.FisheyeReviewItemData;
import com.atlassian.crucible.spi.data.GeneralCommentData;
import com.atlassian.crucible.spi.data.ReviewData;
import com.atlassian.crucible.spi.data.VersionedLineCommentData;

/**
 * Interface that specifies the entry points to the Crucible API.
 * 
 * @author Ross Rowe
 * 
 */
public interface CrucibleClient {

	/**
	 * Returns the list of {@link GeneralCommentData} instances for the reviewId.
	 * 
	 * @param reviewId
	 * @return
	 */
	List<GeneralCommentData> getGeneralComments(String reviewId);

	/**
	 * Retrieves the {@link ReviewData} instance for the reviewId.
	 * 
	 * @param reviewId
	 * @return
	 */
	ReviewData getReview(String reviewId);

	/**
	 * Returns a list of {@link VersionedLineCommentData} instances for the reviewId.
	 * 
	 * @param reviewId
	 * @return
	 */
	List<VersionedLineCommentData> getVersionedComments(String reviewId);

	/**
	 * Performs a login action using the username and password.
	 * 
	 * @param username
	 * @param password
	 * @return
	 */
	String login(String username, String password);

	/**
	 * Retrieves the {@link FisheyeReviewItemData} instance for the reviewId and
	 * the reviewItemId.
	 * 
	 * @param reviewId
	 * @param reviewItemId
	 * @return
	 */
	FisheyeReviewItemData getReviewItemData(String reviewId, String reviewItemId);

	/**
	 * Returns a user's real name.
	 * 
	 * @param userId
	 * @return
	 */
	String getUserName(String userId);
}
